LocalAiService class abstract

Interface for local CLI-based AI services

Inheritance
Implementers

Constructors

LocalAiService()

Properties

cliCommand String
Get the CLI command name
no setter
hashCode int
The hash code for this object.
no setterinherited
providerType AiProviderType
Get the provider type
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateCodeReview(CoverageData coverage, List<String> files) Future<String>
Generate code review based on coverage data
inherited
generateCodeReviewHtml(CoverageData coverage, List<String> files, String outputPath) Future<String>
Generate HTML file for code review
inherited
generateInsights(CoverageData coverage) Future<String>
Generate insights about coverage patterns
inherited
generateInsightsHtml(CoverageData coverage, String outputPath) Future<String>
Generate HTML file for insights
inherited
getCliVersion() Future<String>
Get the CLI tool version
isAvailable() Future<bool>
Check if the AI service is available
inherited
isCliInstalled() Future<bool>
Check if the CLI tool is installed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited