CoverageData class
Represents parsed coverage data from LCOV files
Constructors
-
CoverageData({required List<
FileCoverage> files, required CoverageSummary summary}) -
Represents parsed coverage data from LCOV files
const
Properties
-
files
→ List<
FileCoverage> -
List of file coverage information
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → CoverageSummary
-
Overall coverage summary
final
Methods
-
copyWith(
{List< FileCoverage> ? files, CoverageSummary? summary}) → CoverageData - Creates a copy of this coverage data with optional modifications
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited