LcovParserImpl class
Implementation of LCOV parser service with optimized parsing for large files
- Implemented types
Constructors
- LcovParserImpl()
-
Implementation of LCOV parser service with optimized parsing for large files
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
filterByFiles(
CoverageData data, List< String> filePaths) → CoverageData -
Filter coverage data by file paths
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseContent(
String content) → Future< CoverageData> -
Parse LCOV content from string
override
-
parseFile(
String filePath) → Future< CoverageData> -
Parse LCOV file
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited